[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [sflphone-kde/abstractmodels] src: [ #24595 ] Fix typo
From:       Emmanuel Lepage Vallee <emmanuel.lepage () savoirfairelinux ! com>
Date:       2013-05-31 19:45:13
Message-ID: 20130531194513.BFFE3A6067 () git ! kde ! org
[Download RAW message or body]

Git commit d3aef78f00d6a7f420b2905678ce0aa58aea79ce by Emmanuel Lepage Vallee.
Committed on 31/05/2013 at 21:45.
Pushed by lepagevalleeemmanuel into branch 'abstractmodels'.

[ #24595 ] Fix typo

M  +2    -2    src/CMakeLists.txt
M  +2    -2    src/delegates/historydelegate.cpp
R  +0    -0    src/icons/tips/ringing.svg [from: src/icons/tips/rigging.svg - 100% \
similarity] M  +1    -1    src/lib/call.cpp
M  +8    -8    src/sflphoneview.cpp
R  +7    -7    src/widgets/tips/ringingtip.cpp [from: src/widgets/tips/riggingtip.cpp \
- 094% similarity] R  +3    -3    src/widgets/tips/ringingtip.h [from: \
src/widgets/tips/riggingtip.h - 095% similarity] M  +9    -9    \
src/widgets/tips/tipcollection.cpp M  +2    -2    src/widgets/tips/tipcollection.h

http://commits.kde.org/sflphone-kde/d3aef78f00d6a7f420b2905678ce0aa58aea79ce

diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 08d0eb5..c38f2a3 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -82,7 +82,7 @@ SET(
    widgets/callviewoverlaytoolbar.cpp
    widgets/tips/conftip.cpp
    widgets/tips/dialpadtip.cpp
-   widgets/tips/riggingtip.cpp
+   widgets/tips/ringingtip.cpp
    widgets/tips/connectionlosttip.cpp
    widgets/tips/tipcollection.cpp
    widgets/tips/removeconferencetip.cpp
@@ -170,7 +170,7 @@ INSTALL( FILES icons/tips/keyboard.svg           DESTINATION  \
${DATA_INSTALL_DIR  INSTALL( FILES icons/tips/upArrow.svg            DESTINATION  \
${DATA_INSTALL_DIR}/sflphone-client-kde/tips )  INSTALL( FILES \
icons/tips/downArrow.svg          DESTINATION  \
${DATA_INSTALL_DIR}/sflphone-client-kde/tips )  INSTALL( FILES \
icons/tips/dragAndDrop.svg        DESTINATION  \
                ${DATA_INSTALL_DIR}/sflphone-client-kde/tips )
-INSTALL( FILES icons/tips/rigging.svg            DESTINATION  \
${DATA_INSTALL_DIR}/sflphone-client-kde/tips ) +INSTALL( FILES icons/tips/ringing.svg \
DESTINATION  ${DATA_INSTALL_DIR}/sflphone-client-kde/tips )  INSTALL( FILES \
icons/tips/reload.svg             DESTINATION  \
${DATA_INSTALL_DIR}/sflphone-client-kde/tips )  INSTALL( FILES \
icons/tips/phoneDown.svg          DESTINATION  \
${DATA_INSTALL_DIR}/sflphone-client-kde/tips )  INSTALL( FILES icons/tips/ring1.svg   \
                DESTINATION  ${DATA_INSTALL_DIR}/sflphone-client-kde/tips )
diff --git a/src/delegates/historydelegate.cpp b/src/delegates/historydelegate.cpp
index eadf21f..239aebe 100644
--- a/src/delegates/historydelegate.cpp
+++ b/src/delegates/historydelegate.cpp
@@ -36,7 +36,7 @@
 #include "klib/configurationskeleton.h"
 #include "widgets/playeroverlay.h"
 #include "delegatedropoverlay.h"
-#include "../widgets/tips/riggingtip.h"
+#include "../widgets/tips/ringingtip.h"
 #include "klib/tipanimationwrapper.h"
 
 static const char* icnPath[4] = {
@@ -212,7 +212,7 @@ void HistoryDelegate::paint(QPainter* painter, const \
QStyleOptionViewItem& optio  else if ((currentState == Call::State::RINGING || \
currentState == Call::State::INCOMING) && index.model()->rowCount() > 1) {  if \
                (!m_AnimationWrapper) {
          ((HistoryDelegate*)this)->m_AnimationWrapper = new TipAnimationWrapper();
-         ((HistoryDelegate*)this)->m_pRingingTip = new RiggingTip();
+         ((HistoryDelegate*)this)->m_pRingingTip = new RingingTip();
          m_AnimationWrapper->setTip(m_pRingingTip);
       }
       if (!m_pRingingTip->isVisible())
diff --git a/src/icons/tips/rigging.svg b/src/icons/tips/ringing.svg
similarity index 100%
rename from src/icons/tips/rigging.svg
rename to src/icons/tips/ringing.svg
diff --git a/src/lib/call.cpp b/src/lib/call.cpp
index 9875df5..ffc296e 100644
--- a/src/lib/call.cpp
+++ b/src/lib/call.cpp
@@ -249,7 +249,7 @@ Call* Call::buildIncomingCall(const QString & callId)
    return call;
 } //buildIncomingCall
 
-///Build a rigging call (from dbus)
+///Build a ringing call (from dbus)
 Call* Call::buildRingingCall(const QString & callId)
 {
    CallManagerInterface& callManager = CallManagerInterfaceSingleton::getInstance();
diff --git a/src/sflphoneview.cpp b/src/sflphoneview.cpp
index 12e2c50..7016bdc 100644
--- a/src/sflphoneview.cpp
+++ b/src/sflphoneview.cpp
@@ -572,7 +572,7 @@ void SFLPhoneView::updateWindowCallState()
             actionTexts     [ SFLPhone::Refuse   ] = ACTION_LABEL_REFUSE         ;
             m_pMessageBoxW->setVisible(false || IM_ACTIVE)   ;
             if (TipCollection::manager()) {
-               TipCollection::manager()->setCurrentTip(TipCollection::rigging());
+               TipCollection::manager()->setCurrentTip(TipCollection::ringing());
             }
             break;
 
@@ -581,7 +581,7 @@ void SFLPhoneView::updateWindowCallState()
             enabledActions  [ SFLPhone::Transfer ] = false                       ;
             m_pMessageBoxW->setVisible(false)                                    ;
             if (TipCollection::manager()) {
-               TipCollection::manager()->setCurrentTip(TipCollection::rigging());
+               TipCollection::manager()->setCurrentTip(TipCollection::ringing());
             }
             break;
 
@@ -674,16 +674,16 @@ void SFLPhoneView::updateWindowCallState()
       }
 
       //Manage tips
-      //There is little way to be sure when to end the rigging animation, for now, \
                brute force the check
-      bool displayRigging = false;
-      if (TipCollection::rigging()->isVisible() || \
TipCollection::manager()->currentTip() == TipCollection::rigging()) { +      //There \
is little way to be sure when to end the ringing animation, for now, brute force the \
check +      bool displayRinging = false;
+      if (TipCollection::ringing()->isVisible() || \
TipCollection::manager()->currentTip() == TipCollection::ringing()) {  foreach (Call* \
                call2, SFLPhone::model()->getCallList()) {
             if(dynamic_cast<Call*>(call2) && (call2->getState() == \
                Call::State::INCOMING || call2->getState() == Call::State::RINGING)) \
                {
-               displayRigging = true;
+               displayRinging = true;
             }
          }
-         if (!displayRigging) {
-            TipCollection::manager()->hideTip(TipCollection::rigging());
+         if (!displayRinging) {
+            TipCollection::manager()->hideTip(TipCollection::ringing());
          }
       }
       if (TipCollection::dragAndDrop()) {
diff --git a/src/widgets/tips/riggingtip.cpp b/src/widgets/tips/ringingtip.cpp
similarity index 94%
rename from src/widgets/tips/riggingtip.cpp
rename to src/widgets/tips/ringingtip.cpp
index c5fb8f8..2217a4d 100644
--- a/src/widgets/tips/riggingtip.cpp
+++ b/src/widgets/tips/ringingtip.cpp
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License      *
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
  ***************************************************************************/
-#include "riggingtip.h"
+#include "ringingtip.h"
 
 //Qt
 #include <QtSvg/QSvgRenderer>
@@ -34,7 +34,7 @@
 #include <cmath>
 
 ///Constructor
-RiggingTip::RiggingTip(QWidget* parent) : \
Tip(QString(),parent),m_pTimer(nullptr),m_Counter(0) +RingingTip::RingingTip(QWidget* \
parent) : Tip(QString(),parent),m_pTimer(nullptr),m_Counter(0)  
 {
    setHasBackground(false);
@@ -49,19 +49,19 @@ RiggingTip::RiggingTip(QWidget* parent) : \
Tip(QString(),parent),m_pTimer(nullptr  }
 
 ///Destructor
-RiggingTip::~RiggingTip()
+RingingTip::~RingingTip()
 {
    if (m_pTimer) delete m_pTimer;
 }
 
 ///Return the image rect
-QRect RiggingTip::getDecorationRect()
+QRect RingingTip::getDecorationRect()
 {
    return QRect(0,0,135,120);
 }
 
 ///Paint the image/decoration
-void RiggingTip::paintDecorations(QPainter& p, const QRect& textRect)
+void RingingTip::paintDecorations(QPainter& p, const QRect& textRect)
 {
    Q_UNUSED(textRect);
    if (!m_pR) {
@@ -113,7 +113,7 @@ void RiggingTip::paintDecorations(QPainter& p, const QRect& \
textRect)  } //paintDecorations
 
 ///Start tip animation, this one implement a few sinus curve to simmulate sound wave
-void RiggingTip::startAnimation(bool visibility)
+void RingingTip::startAnimation(bool visibility)
 {
    if (!m_pTimer && visibility) {
       m_pTimer = new QTimer(this);
@@ -129,7 +129,7 @@ void RiggingTip::startAnimation(bool visibility)
 } //startAnimation
 
 ///Next animation frame
-void RiggingTip::timeout()
+void RingingTip::timeout()
 {
    m_Counter += 1; //Animation speed
    if (m_Counter > 35)
diff --git a/src/widgets/tips/riggingtip.h b/src/widgets/tips/ringingtip.h
similarity index 95%
rename from src/widgets/tips/riggingtip.h
rename to src/widgets/tips/ringingtip.h
index a2ce6eb..dc72476 100644
--- a/src/widgets/tips/riggingtip.h
+++ b/src/widgets/tips/ringingtip.h
@@ -31,12 +31,12 @@ class QSvgRenderer;
 class QPainter;
 
 ///A tip to be passed to the TipLoader
-class RiggingTip : public Tip
+class RingingTip : public Tip
 {
    Q_OBJECT
 public:
-   explicit RiggingTip(QWidget* parent = nullptr);
-   virtual ~RiggingTip();
+   explicit RingingTip(QWidget* parent = nullptr);
+   virtual ~RingingTip();
 
    //It is not a notification, it doesn't need to be as visible
    virtual float opacity() { return 0.5f; }
diff --git a/src/widgets/tips/tipcollection.h b/src/widgets/tips/tipcollection.h
index 642ae25..33ff463 100644
--- a/src/widgets/tips/tipcollection.h
+++ b/src/widgets/tips/tipcollection.h
@@ -34,7 +34,7 @@ public:
    //Call related
    static Tip*        endCall();
    static Tip*        endBusy();
-   static Tip*        rigging();
+   static Tip*        ringing();
    static Tip*        removeConference();
    
    //Account related
@@ -54,7 +54,7 @@ private:
    //Call related
    static Tip*        m_spEndCall;
    static Tip*        m_spEndBusy;
-   static Tip*        m_spRigging;
+   static Tip*        m_spRinging;
    static Tip*        m_spRemoveConference;
    
    //Account related


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff --git a/src/widgets/tips/tipcollection.cpp b/src/widgets/tips/tipcollection.cpp
index 1e545c1..9545932 100644
--- a/src/widgets/tips/tipcollection.cpp
+++ b/src/widgets/tips/tipcollection.cpp
@@ -20,7 +20,7 @@
 #include <KLocale>
 
 #include "dialpadtip.h"
-#include "riggingtip.h"
+#include "ringingtip.h"
 #include "connectionlosttip.h"
 #include "conftip.h"
 #include "removeconferencetip.h"
@@ -33,7 +33,7 @@ ConfTip*           TipCollection::m_spConf             = nullptr;
 //Call related
 Tip*               TipCollection::m_spEndCall          = nullptr;
 Tip*               TipCollection::m_spEndBusy          = nullptr;
-Tip*               TipCollection::m_spRigging          = nullptr;
+Tip*               TipCollection::m_spRinging          = nullptr;
 Tip*               TipCollection::m_spRemoveConference = nullptr;
 
 //Account related
@@ -91,15 +91,15 @@ Tip* TipCollection::endBusy()
    return m_spEndBusy;
 }
 
-///Return rigging tip
-Tip* TipCollection::rigging()
+///Return ringing tip
+Tip* TipCollection::ringing()
 {
-   if (!m_spRigging) {
-      m_spRigging = new RiggingTip();
-      m_spRigging->setAnimationIn(Tip::TipAnimation::Fade);
-      m_spRigging->setAnimationOut(Tip::TipAnimation::Fade);
+   if (!m_spRinging) {
+      m_spRinging = new RingingTip();
+      m_spRinging->setAnimationIn(Tip::TipAnimation::Fade);
+      m_spRinging->setAnimationOut(Tip::TipAnimation::Fade);
    }
-   return m_spRigging;
+   return m_spRinging;
 }
 
 //Account related